@@ -18,10 +18,10 @@ class JobError(Exception):
         self.message = data
 
     def __repr__(self):
-        return "JobError({self.status}, {self.message!r})".format(self=self)
+        return "JobError({self.status}, {self.message})".format(self=self)
 
     def __str__(self):
-        return "JobError({self.status}, {self.message!r})".format(self=self)
+        return "JobError({self.status}, {self.message})".format(self=self)
 
 
 class DatasetError(Exception):
@@ -31,8 +31,7 @@ class DatasetError(Exception):
         self.message = data
 
     def __repr__(self):
-        return "JobError({self.status}, {self.message!r})".format(self=self)
+        return "DatasetError({self.status}, {self.message})".format(self=self)
 
     def __str__(self):
-        return "JobError({self.status}, {self.message!r})".format(self=self)
-        
\ No newline at end of file
+        return "DatasetError({self.status}, {self.message})".format(self=self)
